OC.L10N.register(
    "core",
    {
    "Please select a file." : "ファイルを選択してください。",
    "File is too big" : "ファイルが大きすぎます",
    "The selected file is not an image." : "選択されたファイルは画像ではありません",
    "The selected file cannot be read." : "選択されたファイルを読み込めませんでした",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブのサイズを超えています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードされたファイルは、HTMLフォームで指定されたMAX_FILE_SIZEディレクティブ制限を超えています",
    "The file was only partially uploaded" : "ファイルは部分的にしかアップロードされていません",
    "No file was uploaded" : "ファイルがアップロードされていません",
    "Missing a temporary folder" : "一時保存フォルダーが見つかりません",
    "Could not write file to disk" : "ファイルをディスクに書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張機能がファイルのアップロードを停止しました",
    "Invalid file provided" : "無効なファイルが提供されました",
    "No image or file provided" : "画像またはファイルが提供されていません",
    "Unknown filetype" : "不明なファイル形式",
    "An error occurred. Please contact your admin." : "エラーが発生しました。管理者に連絡してください。",
    "Invalid image" : "無効な画像",
    "No temporary profile picture available, try again" : "一時的なプロファイル用画像が利用できません。もう一度試してください",
    "No crop data provided" : "クロップデータが提供されていません",
    "No valid crop data provided" : "有効なクロップデータが提供されていません",
    "Crop is not square" : "クロップが正方形ではありません",
    "State token does not match" : "状態トークンが一致しません",
    "Invalid app password" : "アプリパスワードが無効です",
    "Could not complete login" : "ログインが完了できませんでした",
    "State token missing" : "状態トークンがありません",
    "Your login token is invalid or has expired" : "あなたのログイントークンは無効か期限が切れています。",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "コミュニティリリースのNextcloudにサポートはなく、プッシュ通知には制限があります",
    "Login" : "ログイン",
    "Unsupported email length (>255)" : "メールアドレスが長すぎます (>255)",
    "Password reset is disabled" : "パスワードリセットは無効化されています",
    "Could not reset password because the token is expired" : "トークンが期限切れのため、パスワードをリセットできませんでした",
    "Could not reset password because the token is invalid" : "トークンが無効なため、パスワードをリセットできませんでした",
    "Password is too long. Maximum allowed length is 469 characters." : "パスワードが長すぎます。使用できる文字数は 469 文字までです",
    "%s password reset" : "%s パスワードリセット",
    "Password reset" : "パスワードのリセット",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "次のボタンをクリックして、パスワードをリセットしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "パスワードをリセットするには、次のリンクをクリックしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
    "Reset your password" : "パスワードをリセット",
    "The given provider is not available" : "指定されたプロバイダは使用できません",
    "Task not found" : "タスクは見つかりません",
    "Internal error" : "内部エラー",
    "Not found" : "見つかりませんでした",
    "Bad request" : "Bad request",
    "Requested task type does not exist" : "要求されたタスクの種類が存在しません",
    "Necessary language model provider is not available" : "必要な言語モデルプロバイダーが利用できません",
    "No text to image provider is available" : "テキストを画像に変換するプロバイダーはありません",
    "Image not found" : "画像が見つかりません",
    "No translation provider available" : "利用可能な翻訳プロバイダーがありません",
    "Could not detect language" : "言語を検出できませんでした",
    "Unable to translate" : "翻訳できませんでした",
    "Nextcloud Server" : "Nextcloud サーバー",
    "Some of your link shares have been removed" : "リンク共有の一部が削除されました",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "セキュリティ上の不具合により、あなたのリンク共有をいくつか削除する必要がありました。 詳しくはリンクをご覧ください。",
    "The account limit of this instance is reached." : "このインスタンスのアカウント制限に達しました。",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "support app にサブスクリプションキーを入力して、アカウント数の上限を増やすことができます。これにより、Nextcloud Enterprise が提供するすべての追加特典が付与され、企業での運用には非常におすすめです。",
    "Learn more ↗" : "もっと詳しく知る",
    "Preparing update" : "アップデートの準備中",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "修復ステップ:",
    "Repair info:" : "修復情報:",
    "Repair warning:" : "修復警告:",
    "Repair error:" : "修復エラー:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "config.phpでブラウザ経由でのアップデートが無効になっていますので、コマンドラインアップデーターをご利用ください。",
    "Turned on maintenance mode" : "メンテナンスモードがオンになりました",
    "Turned off maintenance mode" : "メンテナンスモードがオフになりました",
    "Maintenance mode is kept active" : "メンテナンスモードが継続中です",
    "Updating database schema" : "データベースのスキーマを更新",
    "Updated database" : "データベース更新済み",
    "Update app \"%s\" from App Store" : "アプリストアから \"%s\" アプリをアップデートする",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "データベーススキーマ %s がアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
    "Updated \"%1$s\" to %2$s" : "%1$sを%2$sに更新しました",
    "Set log level to debug" : "ログをデバッグレベルに設定",
    "Reset log level" : "ログレベルをリセット",
    "Starting code integrity check" : "コード整合性の確認を開始",
    "Finished code integrity check" : "コード整合性の確認が終了",
    "%s (incompatible)" : "%s (非互換)",
    "The following apps have been disabled: %s" : "次のアプリが無効になりました: %s ",
    "Already up to date" : "すべて更新済",
    "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
    "For more details see the {linkstart}documentation ↗{linkend}." : "詳細については、{linkstart}ドキュメント↗{linkend}を参照してください。",
    "unknown text" : "不明なテキスト",
    "Hello world!" : "Hello world!",
    "sunny" : "快晴",
    "Hello {name}, the weather is {weather}" : "こんにちは､ {name}､ 天気は{weather}です",
    "Hello {name}" : " {name}さん､こんにちは",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>これが検索結果です<script>alert(1)</script></strong>",
    "new" : "新規",
    "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "更新が進行中です。このページを離れると一部の環境では処理が中断されてしまう可能性があります。",
    "Update to {version}" : "{version} にアップデート",
    "An error occurred." : "エラーが発生しました。",
    "Please reload the page." : "ページをリロードしてください。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "アップデートできませんでした。この問題に対する詳細な情報については、<a href=\"{url}\">フォーラムの投稿を確認してください</a> ",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "アップデートできませんでした。<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud コミュニティ</a> に問題を報告してください。",
    "Continue to {productName}" : "{productName} に進む",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["アップデートできました。%n秒で {productName}にリダイレクトします。"],
    "Applications menu" : "アプリケーションメニュー",
    "Apps" : "アプリ",
    "More apps" : "さらにアプリ",
    "_{count} notification_::_{count} notifications_" : ["通知 {count} 件"],
    "No" : "いいえ",
    "Yes" : "はい",
    "Federated user" : "フェデレーションユーザー",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "共有を作成",
    "The remote URL must include the user." : "リモートURLにはユーザーを含める必要があります。",
    "Invalid remote URL." : "無効なリモートURLです。",
    "Failed to add the public link to your Nextcloud" : "このNextcloudに公開リンクを追加できませんでした",
    "Direct link copied to clipboard" : "クリップボードにコピーされた直接リンク",
    "Please copy the link manually:" : "手動でリンクをコピーしてください：",
    "Custom date range" : "カスタム日付の範囲",
    "Pick start date" : "開始日を指定",
    "Pick end date" : "終了日を指定",
    "Search in date range" : "日付の範囲で検索",
    "Search in current app" : "現在のアプリケーションで検索",
    "Clear search" : "検索をクリア",
    "Search everywhere" : "あらゆる場所を検索",
    "Unified search" : "統合検索",
    "Search apps, files, tags, messages" : "アプリ、ファイル、タグ、メッセージを検索",
    "Places" : "場所",
    "Date" : "日付",
    "Today" : "今日",
    "Last 7 days" : "7日以内",
    "Last 30 days" : "30日以内",
    "This year" : "今年",
    "Last year" : "去年",
    "Search people" : "人物を検索",
    "People" : "人間",
    "Filter in current view" : "現在のビューでフィルタ",
    "Results" : "結果",
    "Load more results" : "次の結果を読み込む",
    "Search in" : "検索対象",
    "Searching …" : "検索しています…",
    "Start typing to search" : "入力して検索を開始します",
    "No matching results" : "一致する結果はありません",
    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "${this.dateFilter.startFrom.toLocaleDateString()} と ${this.dateFilter.endAt.toLocaleDateString()} の間",
    "Log in" : "ログイン",
    "Logging in …" : "ログイン中...",
    "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
    "Please contact your administrator." : "管理者にお問い合わせください。",
    "Temporary error" : "一時的なエラー",
    "Please try again." : "もう一度お試しください。",
    "An internal error occurred." : "内部エラーが発生しました。",
    "Please try again or contact your administrator." : "もう一度やり直してみるか、管理者にお問い合わせください。",
    "Password" : "パスワード",
    "Log in to {productName}" : "{productName} へログイン",
    "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
    "This account is disabled" : "アカウントが無効化されています",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
    "Account name or email" : "アカウント名またはメールアドレス",
    "Account name" : "アカウント名",
    "Log in with a device" : "デバイスを使ってログインする",
    "Login or email" : "ログイン名またはEメール",
    "Your account is not setup for passwordless login." : "あなたのアカウントはパスワードなしでログインできるように設定されていません。",
    "Browser not supported" : "サポートされていないブラウザーです",
    "Passwordless authentication is not supported in your browser." : "お使いのブラウザーはパスワードレス認証に対応していません。",
    "Your connection is not secure" : "この接続は安全ではありません",
    "Passwordless authentication is only available over a secure connection." : "パスワードレス認証は、セキュアな接続でのみ利用可能です。",
    "Reset password" : "パスワードをリセット",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在する場合、パスワードリセットメッセージがメールアドレスに送信されています。もしメッセージが届かない場合は、メールアドレスやログイン名を確認するか、迷惑メールフォルダをチェックするか、もしくは管理者にお問い合わせください。",
    "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
    "Password cannot be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。",
    "Back to login" : "ログインに戻る",
    "New password" : "新しいパスワードを入力",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ファイルが暗号化されます。パスワードがリセットされた後は、データを元に戻すことはできません。対処方法がわからない場合は、続行する前に管理者に問い合わせてください。本当に続行しますか?",
    "I know what I'm doing" : "どういう操作をしているか理解しています",
    "Resetting password" : "パスワードのリセット",
    "Recommended apps" : "推奨アプリ",
    "Loading apps …" : "アプリを読み込み中…",
    "Could not fetch list of apps from the App Store." : "App Storeからアプリのリストを取得できませんでした。",
    "App download or installation failed" : "アプリのダウンロードまたはインストールに失敗しました",
    "Cannot install this app because it is not compatible" : "アプリの互換性がないため、インストールできません",
    "Cannot install this app" : "このアプリはインストールできません",
    "Skip" : "スキップ",
    "Installing apps …" : "アプリをインストールしています…",
    "Install recommended apps" : "推奨アプリをインストール",
    "Schedule work & meetings, synced with all your devices." : "すべての端末と同期して、仕事と会議をスケジュールに組み込みます",
    "Keep your colleagues and friends in one place without leaking their private info." : "個人情報を漏らさずに、同僚や友人をまとめて保管します。",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ファイル、連絡先、カレンダーとうまく合わさったシンプルなメールアプリ。",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online上に構築された、共同作業ドキュメント、スプレッドシート、およびプレゼンテーション",
    "Distraction free note taking app." : "集中モードメモアプリ",
    "Settings menu" : "メニュー設定",
    "Avatar of {displayName}" : "{displayName} のアバター",
    "Search contacts" : "連絡先を検索",
    "Reset search" : "検索をリセットする",
    "Search contacts …" : "連絡先を検索...",
    "Could not load your contacts" : "連絡先を読み込めませんでした",
    "No contacts found" : "連絡先が見つかりません",
    "Show all contacts" : "すべての連絡先を表示",
    "Install the Contacts app" : "連絡先アプリをインストール",
    "Loading your contacts …" : "連絡先を読み込み中...",
    "Looking for {term} …" : "{term} を確認中 ...",
    "Search starts once you start typing and results may be reached with the arrow keys" : "入力が始まると検索が始まり、矢印キーで検索結果を表示することができます",
    "Search for {name} only" : "{name}のみを検索",
    "Loading more results …" : "次の結果を読み込み中 ...",
    "Search" : "検索",
    "No results for {query}" : "{query}の検索結果はありません",
    "Press Enter to start searching" : "Enterキーを押して検索を開始",
    "An error occurred while searching for {type}" : "{type} の検索中にエラーが発生しました",
    "Forgot password?" : "パスワードをお忘れですか?",
    "Back to login form" : "ログイン画面に戻る",
    "Back" : "戻る",
    "Login form is disabled." : "ログインフォームは無効です。",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud ログインフォームは無効になっています。 利用可能な場合は別のログインオプションを使用するか、管理者に問い合わせてください。",
    "Edit Profile" : "プロフィールを編集",
    "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
    "You have not added any info yet" : "まだ情報が追加されていません",
    "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
    "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
    "More actions" : "その他のアクション",
    "This browser is not supported" : "お使いのブラウザーはサポートされていません",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "お使いのブラウザーはサポート対象外です。新しいバージョンにアップグレードするかサポートされているブラウザーへ切り替えてください",
    "Continue with this unsupported browser" : "サポート対象外のブラウザーで継続する",
    "Supported versions" : "サポート対象バージョン",
    "{name} version {version} and above" : "{name} バージョン {version} 以上が対象",
    "Search {types} …" : "{types} を検索…",
    "Choose {file}" : "{file}を選択",
    "Choose" : "選択",
    "Copy to {target}" : "{target} にコピー",
    "Copy" : "コピー",
    "Move to {target}" : "{target} に移動",
    "Move" : "移動",
    "OK" : "OK",
    "read-only" : "読み取り専用",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} ファイルが競合"],
    "One file conflict" : "1ファイルが競合",
    "New Files" : "新しいファイル",
    "Already existing files" : "既存のファイル",
    "Which files do you want to keep?" : "どちらのファイルを保持しますか？",
    "If you select both versions, the copied file will have a number added to its name." : "両方のバージョンを選択した場合は、ファイル名の後ろに数字を追加したファイルのコピーを作成します。",
    "Cancel" : "キャンセル",
    "Continue" : "続ける",
    "(all selected)" : "(すべて選択)",
    "({count} selected)" : "({count} 選択)",
    "Error loading file exists template" : "既存ファイルのテンプレートの読み込みエラー",
    "Saving …" : "保存中...",
    "seconds ago" : "数秒前",
    "Connection to server lost" : "サーバーとの接続が切断されました",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ページの読み込み中に問題が発生しました。%n秒後に再読み込みします"],
    "Add to a project" : "プロジェクトに追加",
    "Show details" : "詳細を表示",
    "Hide details" : "詳細を隠す",
    "Rename project" : "プロジェクト名を変更",
    "Failed to rename the project" : "プロジェクト名の変更に失敗",
    "Failed to create a project" : "プロジェクトの作成に失敗",
    "Failed to add the item to the project" : "プロジェクトへのアイテムの追加に失敗",
    "Connect items to a project to make them easier to find" : "アイテムをプロジェクトに接続して見つけやすくする",
    "Type to search for existing projects" : "入力して既存のプロジェクトを検索します",
    "New in" : "新機能",
    "View changelog" : "変更履歴を確認する",
    "Very weak password" : "非常に弱いパスワード",
    "Weak password" : "弱いパスワード",
    "So-so password" : "まずまずのパスワード",
    "Good password" : "良好なパスワード",
    "Strong password" : "強いパスワード",
    "No action available" : "操作できません",
    "Error fetching contact actions" : "連絡先操作取得エラー",
    "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\"ダイアログを閉じる",
    "Email length is at max (255)" : "メールアドレスの長さは 255文字 以下です",
    "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
    "Restricted" : "制限付き",
    "Invisible" : "オフライン",
    "Delete" : "削除",
    "Rename" : "名前の変更",
    "Collaborative tags" : "コラボタグ",
    "No tags found" : "タグが見つかりません",
    "Personal" : "個人",
    "Accounts" : "アカウント",
    "Admin" : "管理",
    "Help" : "ヘルプ",
    "Access forbidden" : "アクセスが禁止されています",
    "Profile not found" : "プロフィールが見つかりません",
    "The profile does not exist." : "プロフィールはありません",
    "Back to %s" : "%s に戻る",
    "Page not found" : "ページが見つかりません",
    "The page could not be found on the server or you may not be allowed to view it." : "サーバーからページを見つけられなかった、もしくは閲覧が許可されていないようです。",
    "Too many requests" : "要求が多すぎます",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ネットワークからのリクエストが多すぎました。このようなエラーが発生した場合は、後で再試行するか、管理者に連絡してください。",
    "Error" : "エラー",
    "Previous" : "前へ",
    "Internal Server Error" : "内部サーバーエラー",
    "The server was unable to complete your request." : "サーバーは要求を完了できませんでした。",
    "If this happens again, please send the technical details below to the server administrator." : "再びこのようなことが起こった場合は、以下の技術情報をサーバー管理者に送ってください。",
    "More details can be found in the server log." : "詳細は、サーバーのログを確認してください。",
    "For more details see the documentation ↗." : "詳細については、ドキュメントを参照してください ↗",
    "Technical details" : "技術詳細",
    "Remote Address: %s" : "リモートアドレス: %s",
    "Request ID: %s" : "リクエスト ID: %s",
    "Type: %s" : "種類: %s",
    "Code: %s" : "コード: %s",
    "Message: %s" : "メッセージ: %s",
    "File: %s" : "ファイル: %s",
    "Line: %s" : "行: %s",
    "Trace" : "トレース",
    "Security warning" : "セキュリティ警告",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
    "Create an <strong>admin account</strong>" : "<strong>管理者アカウント</strong>を作成してください",
    "Show password" : "パスワードを表示",
    "Toggle password visibility" : "パスワードの表示/非表示を切り替える",
    "Storage & database" : "ストレージとデータベース",
    "Data folder" : "データフォルダー",
    "Configure the database" : "データベースを設定してください",
    "Only %s is available." : "%s のみ有効です。",
    "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
    "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
    "Database account" : "データベースアカウント",
    "Database password" : "データベースのパスワード",
    "Database name" : "データベース名",
    "Database tablespace" : "データベースの表領域",
    "Database host" : "データベースのホスト名",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
    "Performance warning" : "パフォーマンス警告",
    "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
    "Install" : "インストール",
    "Installing …" : "インストールしています…",
    "Need help?" : "ヘルプが必要ですか？",
    "See the documentation" : "ドキュメントを確認してください",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloudを再インストールしようとしているようです。 しかし、CAN_INSTALLファイルがconfigディレクトリにありません。 続行するには、configフォルダーにCAN_INSTALLファイルを作成してください。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "設定フォルダーからCAN_INSTALLを削除できませんでした。 このファイルを手動で削除してください。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "このアプリケーションの動作にはJavaScriptが必要です。\n {linkstart}JavaScriptを有効にし{linkend} 、ページを更新してください。 ",
    "Skip to main content" : "メインコンテンツへスキップ",
    "Skip to navigation of app" : "アプリのナビゲーションにスキップする",
    "Go to %s" : "%sに移動",
    "Get your own free account" : "無料でアカウントを作成する",
    "Connect to your account" : "あなたのアカウントに接続する",
    "Please log in before granting %1$s access to your %2$s account." : "あなたの %2$s アカウントに %1$s アクセスを許可する前にログインしてください。",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "新しいデバイスやアプリを設定しようとしていないのに、今この画面が表示された場合、誰かがあなたを騙してデータへのアクセス権を奪取しようとしています。その場合は、ここで止めてシステム管理者に連絡してください。",
    "App password" : "アプリパスワード",
    "Grant access" : "アクセスを許可",
    "Alternative log in using app password" : "アプリパスワードを使用した代替ログイン",
    "Account access" : "アカウントによるアクセス許可",
    "Currently logged in as %1$s (%2$s)." : "現在、%1$s (%2$s)としてログインしています。",
    "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可",
    "Account connected" : "アカウント接続済",
    "Your client should now be connected!" : "クライアントはもう接続されているはずです！",
    "You can close this window." : "このウィンドウは閉じてしまって構いません。",
    "This share is password-protected" : "この共有はパスワードで保護されています",
    "The password is wrong or expired. Please try again or request a new one." : "パスワードが間違っているか有効期限切れです。後で再度お試しいただくか、新しいパスワードをリクエストしてください。",
    "Please type in your email address to request a temporary password" : "仮パスワードを申請するためにメールアドレスを入力してください。",
    "Email address" : "メールアドレス",
    "Password sent!" : "パスワードを送信しました",
    "You are not authorized to request a password for this share" : "この共有のためのパスワードを要求する権限はありません。",
    "Two-factor authentication" : "二要素認証",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "このアカウントは強化セキュリティが適用されています。二要素認証を行ってください。",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "有効な二要素認証方式のうち少なくとも1つをロードできませんでした。 管理者に連絡してください。",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "二要素認証が強制されていますが、アカウントに設定されていません。 不明な点は管理者に連絡してください。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "二要素認証が強制されていますが、アカウントに設定されていません。 二要素認証をセットアップしてください。",
    "Set up two-factor authentication" : "二要素認証を設定",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "二要素認証が強制されていますが、アカウントに設定されていません。 バックアップコードを使用してログインするか、不明点は管理者に連絡してください。",
    "Use backup code" : "バックアップコードを使用する",
    "Cancel login" : "ログインをキャンセル",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "アカウントのセキュリティ強化が必要です。使用する認証手段を選択してください。",
    "Error while validating your second factor" : "第二要素の検証でエラーが発生しました",
    "Access through untrusted domain" : "信頼できないドメインを介したアクセス",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "管理者に連絡してください。 管理者の場合は、config.sample.phpを参照して config/config.phpの \"trusted_domains\" を設定してください。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "これを構成する方法の詳細は、%1$sドキュメント%2$sにあります。",
    "App update required" : "アプリの更新が必要",
    "%1$s will be updated to version %2$s" : "%1$s は バーション %2$s にアップデートされます",
    "The following apps will be updated:" : "以下のアプリはアップデートされます:",
    "These incompatible apps will be disabled:" : "無効になる互換性のないアプリ:",
    "The theme %s has been disabled." : "テーマ %s が無効になっています。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "データベースを確認してください。実行前にconfigフォルダーとdataフォルダーをバックアップします。",
    "Start update" : "アップデートを開始",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "大規模なサイトの場合、ブラウザーがタイムアウトする可能性があるため、インストールディレクトリで次のコマンドを実行することもできます。",
    "Detailed logs" : "詳細ログ",
    "Update needed" : "更新が必要です",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50人以上のアカウントを持つ大規模なインスタンスの場合は、コマンドラインのアップデータを使用してください。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "不明な場合、  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ドキュメント</a>を参照してください。",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Web 画面から続行すると危険性があることを理解しています。この操作がタイムアウトすると、データが失われる危険性があることを理解しています。もし失敗した場合には取得済みのバックアップから修復する方法を理解しています。",
    "Upgrade via web on my own risk" : "危険性を理解した上でWeb画面からアップグレード",
    "Maintenance mode" : "メンテナンスモード",
    "This %s instance is currently in maintenance mode, which may take a while." : "このサーバー %s は現在メンテナンスモードです。しばらくお待ちください。",
    "This page will refresh itself when the instance is available again." : "この画面は、サーバー の再起動後に自動的に更新されます。",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続き、または予期せず現れる場合は、システム管理者に問い合わせてください。",
    "The user limit of this instance is reached." : "このインスタンスのユーザー制限に達しました。",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "サポートappへサブスクリプションキーを入力すると、ユーザー数の上限を増やすことができます。また、Nextcloud Enterpriseが提供するすべての追加特典が付与されますので、企業で運用に必須です",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。これは、このフォルダーを直接配信するように更新されていないWebサーバー構成が影響している可能性があります。構成を、Apacheの \".htaccess\" にある設定済みの書き換えルールまたはNginxのドキュメントの{linkstart}ドキュメントページ↗{linkend}で提供されているルールと比較してください。 Nginxでは、これらは通常、修正が必要な \"location〜\" で始まる行です。",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Webサーバーで.woff2ファイルが配信されるように適切に設定されていません。これは通常、Nginx構成の問題です。 Nextcloud 15の場合、.woff2ファイルも配信するように調整する必要があります。 Nginx構成を{linkstart}ドキュメント↗{linkend}の推奨構成と比較してください。",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "安全な接続でインスタンスにアクセスしていますが、インスタンスは安全でないURLを生成しています。これは、リバースプロキシの背後にあり、構成設定変数が正しく上書きされていない可能性があります。これについては、{linkend}ドキュメントページ↗{linkstart}をお読みください。",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "データディレクトリやファイルがインターネットからアクセスされている可能性があります。.htaccessファイルが機能していません。データディレクトリにアクセスできないようにWebサーバーを設定するか、データディレクトリをWebサーバーのドキュメントルートの外に移動することを強くお勧めします。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 一部の機能は正しく機能しない可能性があります。この設定を調整することを推奨します。",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーに \"{expected}\"が含まれていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします。",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTPヘッダの\"{header}\"に\"{val1}\"、\"{val2}\"、\"{val3}\"、\"{val4}\"、\"{val5}\"が設定されていません。これにより、リファラー情報が漏洩する可能性があります。 {linkstart} W3C勧告↗{linkend}を参照してください。",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Strict-Transport-Security \"HTTP ヘッダーの秒数が少なくとも\"{seconds}\" に設定されていません。セキュリティを強化するには、{linkstart}セキュリティのヒント↗{linkend}で説明されているようにHSTSを有効にすることをお勧めします。",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "HTTP 経由で安全ではないサイトにアクセスします。 {linkstart}セキュリティのヒント ↗{linkend} で説明されているように、代わりに HTTPS を要求するようにサーバーを設定することを強くお勧めします。これがないと、「クリップボードにコピー」や「Service Worker」などの一部の重要な Web 機能が動作しません！",
    "Currently open" : "編集中",
    "Wrong username or password." : "ユーザー名またはパスワードが間違っています",
    "User disabled" : "ユーザーは無効です",
    "Login with username or email" : "ログインするユーザー名またはメールアドレス",
    "Login with username" : "ログインするユーザー名",
    "Username or email" : "ユーザー名またはメールアドレス",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在したら、パスワード変更のメッセージがそのメールアドレスに送信されます。\nもしメールが届いていない場合は、メールアドレスまたはアカウント名を確認するか、メールが迷惑メールフォルダに入っていないか確認するか、もしくは管理者にお問い合わせください。",
    "Apps and Settings" : "アプリと設定",
    "Error loading message template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
    "Users" : "ユーザー",
    "Username" : "ユーザー名",
    "Database user" : "データベースのユーザー名",
    "This action requires you to confirm your password" : "この操作では、パスワードを確認する必要があります",
    "Confirm your password" : "パスワードを確認",
    "Confirm" : "確認",
    "App token" : "アプリのトークン",
    "Alternative log in using app token" : "アプリトークンを使って代替ログイン",
    "Please use the command line updater because you have a big instance with more than 50 users." : "50人以上が使う大規模システムの場合は、コマンドラインでアップグレードを行ってください。"
},
"nplurals=1; plural=0;");
